import { Modal, Form, Select, Input, Radio } from 'antd'
import { forwardRef, useImperativeHandle, useState } from 'react'
import adTypeState from '@src/store/globalStates/adTypeState'
import styles from './index.module.css'
import type { RowDataType } from '../ContentTable/types'
import type { 
  PropsType, Action, FormDataType, 
  OptionsItemType, RadioOptionsType 
} from './types'

const { Item, useForm, useWatch } = Form
const initialValues = {
  unionAdPosition: 0, // 广告位类型
}

const CreateModal = forwardRef(({ allAppList, onCreate, onUpdate }:PropsType, ref) => {
  const [isOpen, setIsOpen] = useState(false)
  const [action, setAction] = useState<Action>()
  const [form] = useForm()
  const [editRow, setEditRow] = useState<RowDataType>()
  const isEdit = action === 'edit'
  const title = isEdit ? '编辑广告位' : '新建广告位'
  const allAppOptions:OptionsItemType[] = allAppList.map(({id, unionAppName})=>({label:unionAppName, value:id}))
  const adTypes = adTypeState.useGlobalState()  
  const applicationId = useWatch('applicationId', form)
  const unionAdPosition = useWatch('unionAdPosition', form)
  const currentApp = allAppList.find(item=>item.id===applicationId)
  const adTypesOptions:RadioOptionsType = Object.entries(adTypes || {}).map(
    ([label,{code}])=>({
      value: +code,
      label,
      disabled: currentApp?.thirdAppType===0 && +code===1 // 应用类型是小程序，banner广告位类型禁用
    })
  )
  if (currentApp?.thirdAppType===0 && unionAdPosition===1) {
    //应用类型是小程序，banner广告位类型会禁用，如果当前选择是banner，需要修改为插屏类型(0)
    form.setFieldValue('unionAdPosition',0)
  }

  useImperativeHandle(ref,()=>({
    open: (editRow?:RowDataType) => {
      setAction(editRow?'edit':'create')
      setEditRow(editRow)
      if (editRow) {
        const {
          applicationId, // 应用id
          unionAdName, // 广告位名称
          unionAdPosition // 广告位类型
        } =  editRow 
        form.setFieldsValue({
          applicationId,
          unionAdName,
          unionAdPosition 
        })
      }
      setIsOpen(true)
    }
  }))

  const onOk = async () => {
    try {
      const res:FormDataType =  await form.validateFields()
      switch (action) {
        case 'create':
          onCreate(res, ()=>{setIsOpen(false)})
          break
        case 'edit':
          onUpdate({...(editRow as RowDataType), ...res},()=>{setIsOpen(false)})
      }
    } catch (error) { /* empty */ }
  }

  const onCancel = () => {
    setIsOpen(false)
  }

  const afterOpenChange = (isOpen: boolean) => {
    if (!isOpen) {
      form.resetFields()
    }
  }

  return (
    <Modal
      className={styles['custom-modal']}
      centered={true}
      open={isOpen}
      title={title}
      width={500}
      onCancel={onCancel}
      onOk={onOk}
      afterOpenChange={afterOpenChange}
    >
      <Form
        form={form}
        initialValues={initialValues}
        labelCol={{ span: 5 }}
        wrapperCol={{ span: 18, offset: 1}}
        colon={ false }
        requiredMark={ false }
      >
        <Item
          name='applicationId'
          label='应用'
          rules={[{ required: true, message: '请选择应用' }]}
        >
          <Select 
            placeholder='请选择应用'
            options={allAppOptions}
          />
        </Item>
        <Item
          name='unionAdName'
          label='广告位名称'
          rules={[{ required: true, message: '请输入广告位名称' }]}
        >
          <Input placeholder='请输入广告位名称' showCount maxLength={ 20 } />
        </Item>
        <Item
          name='unionAdPosition'
          label='广告位类型'
          rules={[{ required: true, message: '请选择广告位类型' }]}
        >
          <Radio.Group options={adTypesOptions} />
        </Item>
      </Form>
    </Modal>
  )
})

export default CreateModal
