import { ReactNode, useState } from 'react'
import { Outlet, useLocation, useNavigate } from 'react-router-dom'
import { Layout, Menu } from 'antd'
import {
  // PieChartOutlined,
  AppstoreOutlined,
} from '@ant-design/icons'
import styles from './index.module.css'

const { Sider, Content } = Layout

export default function Index(){
  const [collapsed, setCollapsed] = useState(false)
  const location = useLocation()
  const navigate = useNavigate()
  
  const {pathname} = location
  const defaultSelectedKeys = [pathname]
  const defaultOpenKeys = findPath(items, pathname)
  
  return (<>
    <Layout className={styles['container']}>
      <Sider 
        className={styles['sider']} 
        theme='light' 
        collapsible 
        collapsed={collapsed} 
        breakpoint='xl'
        onCollapse={(v)=>setCollapsed(v)}
        collapsedWidth={60}
      >
        <Menu 
          defaultSelectedKeys={defaultSelectedKeys} 
          defaultOpenKeys={defaultOpenKeys}
          mode="inline" 
          items={items} 
          onSelect={(v)=>{navigate(v.key)}}
        />
      </Sider>
      <Content className={styles['content']}>
        <Outlet/>
      </Content>
    </Layout>
  </>)
}

const items: MenuItem[] = [
  {
    label: '广告设置',
    key: 'manage',
    icon: <AppstoreOutlined />,
    children: [
      {
        label: '应用列表',
        key: '/manage/app-manage'
      },
      {
        label: '广告位列表',
        key: '/manage/ad-manage',
      }
    ]
  },
  // {
  //   label: '广告数据',
  //   key: '/manage/ad-data',
  //   icon: <PieChartOutlined />
  // }
]

interface MenuItem {
  label: string,
  key: string,
  icon?: ReactNode,
  children?: MenuItem[],
  types?: string
}

function findPath(menus:MenuItem[],findKey:string): string[]|undefined {
  const path: string[] =  []

  function dfs(items:MenuItem[]): boolean {
    for (let i = 0; i < items.length; i++) {
      const {key,children} = items[i]
      path.push(key)
      if (key===findKey) 
        return true
      if (children?.length && dfs(children)) 
        return true
      path.pop()
    }
    return false
  }
  
  return dfs(menus) ? path : undefined
}